@@ -33,7 +33,8 @@ C_ = util.C_
 
 class Spec():
     def __init__(self, spec:dict):
-        assert isinstance(spec, dict), f"spec must be a dict. got: {type(spec)}"
+        if not isinstance(spec, dict):
+            raise SpecIssue(400,f"spec must be a dict. got: {type(spec)}")
 
         self.raw_spec = spec
 
@@ -46,25 +47,30 @@ class Spec():
         def _te(_v): return f"Illegal type passed in spec: {_v}. Legal types are: {_legal_types}"
 
         for fld, v in spec.items():
-            assert util.isAlphaNumUscore(fld), f"dict keys must be a variable syntax (alpha/num/uscore) only. Got: {fld}"
+            if not util.isAlphaNumUscore(fld):
+                raise SpecIssue(401, f"dict keys must be a variable syntax (alpha/num/uscore) only. Got: {fld}")
             
             type_c = None
             allow_null = False
             if isinstance(v, tuple):
-                assert len(v) == 2, "tuple must have two values only <T> and None."
+                if len(v) != 2:
+                    raise SpecIssue(402, "tuple must have two values only <T> and None.")
                 
                 extra_t = list(set(v) - set( (None,) ) )
 
-                assert len(extra_t) == 1,f"types tuple must only have one type and None"
+                if len(extra_t) != 1:
+                    raise SpecIssue(402, f"types tuple must only have one type and None")
 
                 type_c = extra_t[0]
                 
-                assert type_c in _legal_types, _te(type_c)
+                if not type_c in _legal_types:
+                    raise SpecIssue(403, _te(type_c))
 
                 allow_null = True
 
             else:
-                assert v in _legal_types, _te(v)
+                if not v in _legal_types:
+                    raise SpecIssue(403, _te(v))
                 type_c = v
 
             self.sp_vars.append(fld)
@@ -79,7 +85,8 @@ class Spec():
 
     def getInfo(self, var:str) -> tuple:
         iF = self.sp_vars.index(var)
-        assert iF > -1, f"FATAL - var {var} not found in Where spec fields: {self.sp_vars}"
+        if iF == -1:
+            raise SpecIssue(401, f"FATAL - field '{var}' not found in Where spec fields: {self.sp_vars}")
         return (self.sp_dtypes[iF], self.sp_allow_null[iF])
 
     def hasVar(self, var):
@@ -405,7 +412,10 @@ def _Where__parse(self):
             if not self.hasVar(_val):
                 raise QueryIssue(301, f"Invalid variable: {_val}. Valid variables: {self.spec.sp_vars}")
 
-            (_clause_dtype, _clause_allow_null) = self.spec.getInfo(_val)
+            try:
+                (_clause_dtype, _clause_allow_null) = self.spec.getInfo(_val)
+            except SpecIssue as ex:
+                raise QueryIssue(301, f"Field ({_val}) not found in spec. Error: {ex.args[0]}")
 
             _clause_tk.append(_val)
 
@@ -607,7 +617,11 @@ class Clause():
         self.oper = oper
 
         # Get Spec info
-        (_sp_dtype, _sp_allow_null) = self._get_wher().spec.getInfo(var)
+        try:
+            (_sp_dtype, _sp_allow_null) = self._get_wher().spec.getInfo(var)
+        except SpecIssue as ex:
+            raise QueryIssue(301, f"Field ({var}) not found in spec. Error: {ex.args[0]}")
+            
         self.sp_dtype = _sp_dtype
         self.allow_null = _sp_allow_null
 
@@ -841,6 +855,20 @@ class QueryIssue(WVExceptBase):
     def _repr__(self):
         return f"<QueryIssue> code: {self.code}, msg: {self.message}"
 
+# SpecIssue codes:
+# 400 = Spec not a Dict
+# 401 = Invalid field
+# 402 = Invalid Value tuple
+# 403 = Invalid type
+# 404 = 
+# 405 = 
+# 406 = 
+class SpecIssue(WVExceptBase):
+    def __str__(self):
+        return self._repr__()
+    def _repr__(self):
+        return f"<SpecIssue> code: {self.code}, msg: {self.message}"
+
 
 class Operator(util.SEnum):
     Equals = '='
